summaryrefslogtreecommitdiffstats
path: root/dcoprss/service.h
diff options
context:
space:
mode:
Diffstat (limited to 'dcoprss/service.h')
-rw-r--r--dcoprss/service.h82
1 files changed, 41 insertions, 41 deletions
diff --git a/dcoprss/service.h b/dcoprss/service.h
index 35cf229e..64a3589e 100644
--- a/dcoprss/service.h
+++ b/dcoprss/service.h
@@ -21,12 +21,12 @@
#include <dcopobject.h>
#include <dcopref.h>
-#include <qdict.h>
-#include <qptrlist.h>
-#include <qstringlist.h>
-#include <qstring.h>
-#include <qdatetime.h>
-#include <qpixmap.h>
+#include <tqdict.h>
+#include <tqptrlist.h>
+#include <tqstringlist.h>
+#include <tqstring.h>
+#include <tqdatetime.h>
+#include <tqpixmap.h>
#include <librss/global.h>
#include <librss/loader.h>
#include <librss/document.h>
@@ -47,7 +47,7 @@ class RSSService : public DCOPObject
private:
- QDict<RSSDocument> m_list;
+ TQDict<RSSDocument> m_list;
public:
RSSService();
@@ -59,14 +59,14 @@ class RSSService : public DCOPObject
k_dcop_signals:
/**
* Emmitted when a new document has been added. You can then
* use document(QString) to get the dcop ref for the object.
* Note: this document may or may not be valid at this
* point so you should connect your dcop signals and then
* do a documentValid() on the dcop ref to make sure of its
* state.
**/
- void added(QString);
+ void added(TQString);
/**
* Emmitted when the document has been removed.
* note at this point the DCOPRef for this object is
@@ -75,7 +75,7 @@ class RSSService : public DCOPObject
* process of loading the document call will be safely ignored
* and you will be notified of the updates.
**/
- void removed(QString);
+ void removed(TQString);
k_dcop:
/**
* Add a new rdf file resource. This will return a dcop reference to the resource. If its a new
@@ -83,50 +83,50 @@ class RSSService : public DCOPObject
* once this reference has been returned you may connect dcop signals and then call
* refresh on the RSSDocument. The document will not be updated until refresh is called.
**/
- DCOPRef add(QString url);
+ DCOPRef add(TQString url);
/**
* Return a list of current rss documents
**/
- QStringList list();
+ TQStringList list();
/**
* Remove an rss document resource. NOTE: Be aware that others may be using this
* resource and if you remove it they may break. Likewise be aware that someone may
* decide to remove your resource on you so you should always check to see if the resource
* is valid before you access it.
**/
- void remove(QString url);
+ void remove(TQString url);
/**
* Return the reference to a requested resource. If this resource is not present a null dcopref is
* returned.
**/
- DCOPRef document(QString url);
+ DCOPRef document(TQString url);
/**
* Exit the RSSService. This will clean everything up and exit.
**/
void exit();
};
-class RSSDocument : public QObject, public DCOPObject
+class RSSDocument : public TQObject, public DCOPObject
{
Q_OBJECT
K_DCOP
private:
bool m_isLoading;
- QString m_Url;
+ TQString m_Url;
Document *m_Doc;
- QPixmap m_pix;
- QPtrList<RSSArticle> m_list;
- QMap<QString,int> m_state;
- QDateTime m_Timeout;
+ TQPixmap m_pix;
+ TQPtrList<RSSArticle> m_list;
+ TQMap<TQString,int> m_state;
+ TQDateTime m_Timeout;
int m_maxAge;
private slots:
- void pixmapLoaded(const QPixmap&);
+ void pixmapLoaded(const TQPixmap&);
void loadingComplete(Loader *, Document, Status);
public:
- RSSDocument(const QString& url);
+ RSSDocument(const TQString& url);
~RSSDocument();
k_dcop_signals:
@@ -161,31 +161,31 @@ class RSSDocument : public QObject, public DCOPObject
/**
* Return the webmaster information from the RSS::Document
**/
- QString webMaster();
+ TQString webMaster();
/**
* Return the manageing editor from the RSS::Document
**/
- QString managingEditor();
+ TQString managingEditor();
/**
* Returns the rating of the RSS::Document
**/
- QString rating();
+ TQString rating();
/**
* Returns the last build date from the RSS::Document
**/
- QDateTime lastBuildDate();
+ TQDateTime lastBuildDate();
/**
* Returns the publication date from the RSS::Document
**/
- QDateTime pubDate();
+ TQDateTime pubDate();
/**
* Returns the copyright information from the RSS::Document
**/
- QString copyright();
+ TQString copyright();
/**
* Returns a list of article titles
**/
- QStringList articles();
+ TQStringList articles();
/**
* Returns the number of articles
**/
@@ -197,27 +197,27 @@ class RSSDocument : public QObject, public DCOPObject
/**
* Returns the link from the RSS::Document
**/
- QString link();
+ TQString link();
/**
* Returns the description from the RSS::Document
**/
- QString description();
+ TQString description();
/**
* Returns the title from the RSS::Document
**/
- QString title();
+ TQString title();
/**
* Returns the text version from the RSS::Document
**/
- QString verbVersion();
+ TQString verbVersion();
/**
* Returns the url for the pixmap from the RSS::Document
**/
- QString pixmapURL();
+ TQString pixmapURL();
/**
* Returns the actual pixmap from the RSS::Document's RSS::Image
**/
- QPixmap pixmap();
+ TQPixmap pixmap();
/**
* Returns if the RSSDocument contains a valid RSS::Document yet.
**/
@@ -249,17 +249,17 @@ class RSSDocument : public QObject, public DCOPObject
* 2 - unread
* 3 - read
*/
- int state( const QString &title) const;
+ int state( const TQString &title) const;
/**
* Set the article state
*/
- void setState( const QString &title, int s );
+ void setState( const TQString &title, int s );
/**
* Convience method that will set a title to read.
*/
- void read( const QString &title);
+ void read( const TQString &title);
};
class RSSArticle : public DCOPObject
@@ -277,14 +277,14 @@ class RSSArticle : public DCOPObject
/**
* Return the articles title
**/
- QString title();
+ TQString title();
/**
* Return the articles description
**/
- QString description();
+ TQString description();
/**
* Return the link to the article
**/
- QString link();
+ TQString link();
};
#endif
@@ -59,14 +59,14 @@ class RSSService : public DCOPObject
/**
* Emmitted when a new document has been added. You can then
- * use document(QString) to get the dcop ref for the object.
+ * use document(TQString) to get the dcop ref for the object.
* Note: this document may or may not be valid at this
* point so you should connect your dcop signals and then